
# Computer Science Niedersachsen

This Library contains often used methods and classes
for Computer Science classes in Niedersachsen (Lower Saxony), Germany.

The initial and main reason for creation of this library
is an implementation of the `Stack` and `Queue` classes,
which differ from the Python implementation.

**Disclaimer:**
Although I try to give my best to provide a useful tool,
I cannot guarantee it always working correctly and being
up-to-date with the latest specifications.

If you encounter a problem, please open an [issue](https://github.com/alexcoder04/cs_nds/issues).

## Installation

This package is available over `pip`:

```sh
pip install cs-nds
```

To use it in your code, just import it:

```python
import cs_nds
```

## Data Structures

 - `Stack` ("Stapel" / stack)
 - `Queue` ("(Warte-)Schlange" / queue)
 - `DynArray` ("Dynamische Reihung" / dynamic array)
 - `BinTree` ("Binärbaum" / binary tree)

